CalendarBuilders<T> class

Class containing all custom builders for TableCalendar.

Constructors

CalendarBuilders({FocusedDayBuilder? prioritizedBuilder, FocusedDayBuilder? todayBuilder, FocusedDayBuilder? selectedBuilder, FocusedDayBuilder? rangeStartBuilder, FocusedDayBuilder? rangeEndBuilder, FocusedDayBuilder? withinRangeBuilder, FocusedDayBuilder? outsideBuilder, FocusedDayBuilder? disabledBuilder, FocusedDayBuilder? holidayBuilder, FocusedDayBuilder? defaultBuilder, HighlightBuilder? rangeHighlightBuilder, SingleMarkerBuilder<T>? singleMarkerBuilder, MarkerBuilder<T>? markerBuilder, DayBuilder? dowBuilder, DayBuilder? headerTitleBuilder, Widget? weekNumberBuilder(BuildContext context, int weekNumber)?, OverlayBuilder? overlayBuilder, OverlayDefaultBuilder? overlayDefaultBuilder})
Creates CalendarBuilders for TableCalendar widget.
const

Properties

defaultBuilder → FocusedDayBuilder?
Custom builder for day cells that do not match any other builder.
final
disabledBuilder → FocusedDayBuilder?
Custom builder for day cells that have been disabled.
final
dowBuilder → DayBuilder?
Custom builder for days of the week labels (Mon, Tue, Wed, etc.).
final
hashCode → int
The hash code for this object.
no setterinherited
headerTitleBuilder → DayBuilder?
Use to customize header's title using different widget
final
holidayBuilder → FocusedDayBuilder?
Custom builder for day cells that are marked as holidays by holidayPredicate.
final
markerBuilder → MarkerBuilder<T>?
Custom builder for event markers. Use to provide your own marker UI for each day cell. Using markerBuilder will override singleMarkerBuilder and default event markers.
final
outsideBuilder → FocusedDayBuilder?
Custom builder for day cells, of which the day.month is different than focusedDay.month. This will affect day cells that do not match the currently focused month.
final
overlayBuilder → OverlayBuilder?
final
overlayDefaultBuilder → OverlayDefaultBuilder?
final
prioritizedBuilder → FocusedDayBuilder?
Custom builder for day cells, with a priority over any other builder.
final
rangeEndBuilder → FocusedDayBuilder?
Custom builder for a day cell that is the end of current range selection.
final
rangeHighlightBuilder → HighlightBuilder?
Custom builder for background highlight of range selection. If isWithinRange is true, then day is within the selected range.
final
rangeStartBuilder → FocusedDayBuilder?
Custom builder for a day cell that is the start of current range selection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedBuilder → FocusedDayBuilder?
Custom builder for day cells that are currently marked as selected by selectedDayPredicate.
final
singleMarkerBuilder → SingleMarkerBuilder<T>?
Custom builder for a single event marker. Each of those will be displayed in a Row above of the day cell. You can adjust markers' position with CalendarStyle properties.
final
todayBuilder → FocusedDayBuilder?
Custom builder for a day cell that matches the current day.
final
weekNumberBuilder → Widget? Function(BuildContext context, int weekNumber)?
Custom builder for number of the week labels.
final
withinRangeBuilder → FocusedDayBuilder?
Custom builder for day cells that fall within the currently selected range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited